Learn R Programming

ecocbo (version 1.0.0)

Underwood_cbo: Cost-Benefit Optimization after Underwood's equations

Description

Applies a cost-benefit optimization model based on either a desired level of precision or a predefined budget, following the approach of Underwood (1997).

Usage

Underwood_cbo(
  comp.var,
  multSE = NULL,
  budget = NULL,
  a = NULL,
  ca = NULL,
  cm = NULL,
  cn
)

Value

A data frame containing the optimized values for m number of sites to sample and n number of samples per site.

Arguments

comp.var

Data frame as obtained from scompvar(), containing variance component estimates

multSE

Optional. Numeric. Required multivariate standard error for the sampling experiment.

budget

Optional. Numeric. Total budget available for the sampling experiment.

a

Numeric. Number of treatments to consider.

ca

Numeric. Cost per treatment.

cm

Numeric. Cost per replicate.

cn

Numeric. Cost per sampling unit.

Author

Edlin Guerra-Castro (edlinguerra@gmail.com), Arturo Sanchez-Porras

References

  • Underwood, A. J. (1997). Experiments in ecology: their logical design and interpretation using analysis of variance. Cambridge university press.

  • Underwood, A. J., & Chapman, M. G. (2003). Power, precaution, Type II error and sampling design in assessment of environmental impacts. Journal of Experimental Marine Biology and Ecology, 296(1), 49-70.

See Also

sim_beta() plot_power() scompvar() sim_cbo()

Examples

Run this code
compVar <- scompvar(data = simResults)

# Optimization based on budget constraint
Underwood_cbo(comp.var = compVar, multSE = NULL, budget = 20000, a = 3, ca = 2500, cn = 100)

# Optimization based on precision constraint
Underwood_cbo(comp.var = compVar, multSE = 0.15, cn = 150)

Run the code above in your browser using DataLab