plot_power() can be used to visualize the power of a study as a
function of the sampling effort. The power curve plot shows that the
power of the study increases as the sample size increases, and the density
plot shows the overlapping areas where \(\alpha\) and \(\beta\) are
significant.
power_curve(powr, m = NULL, n, cVar, model)Power curves for the different values of 'm'. The selected, or computed, 'n' is marked in white with a bold outline.
The value of the selected 'm', 'n' and the corresponding component of variation are presented in all methods.
Part of the object of class "ecocbo_beta" that results from
sim_beta().
Calculated in plot_power(). When using the single.factor model,
m is NULL.
Calculated in plot_power().
Calculated variation components.
Model used for calculating power. Options, so far, are 'single.factor' and 'nested.symmetric'.
Edlin Guerra-Castro (edlinguerra@gmail.com), Arturo Sanchez-Porras
Underwood, A. J. (1997). Experiments in ecology: their logical design and interpretation using analysis of variance. Cambridge university press.
Underwood, A. J., & Chapman, M. G. (2003). Power, precaution, Type II error and sampling design in assessment of environmental impacts. Journal of Experimental Marine Biology and Ecology, 296(1), 49-70.
sim_beta()
scompvar()
sim_cbo()
prep_data()
plot_power()